@@ -140,7 +140,7 @@ void Control::Draw(int x, int y, size_t w, size_t h)
 
 bool Control::HandleMouseEvent(const Lum::OS::MouseEvent& event)
 {
-  if (showAll) {
+  if (showAll || !image.Valid()) {
     return false;
   }
 
