@@ -27,26 +27,19 @@
 #include <Lum/Label.h>
 #include <Lum/Panel.h>
 #include <Lum/Space.h>
-#include <Lum/WindowGroup.h>
 
 ImageInfo::ImageInfo(Image* image)
  : image(image)
 {
-  AttachModel(GetClosedAction());
-}
-
-ImageInfo::~ImageInfo()
-{
-  UnattachModel(GetClosedAction());
+  Observe(GetClosedAction());
 }
 
 void ImageInfo::PreInit()
 {
-  Lum::Button           *button;
-  Lum::ButtonRow        *buttonRow;
-  Lum::Label            *label;
-  Lum::Panel            *panel;
-  Lum::WindowGroup      *container;
+  Lum::Button    *button;
+  Lum::ButtonRow *buttonRow;
+  Lum::Label     *label;
+  Lum::Panel     *panel;
 
   panel=new Lum::VPanel();
 
@@ -70,10 +63,7 @@ void ImageInfo::PreInit()
 
   panel->Add(buttonRow);
 
-  container=new Lum::WindowGroup();
-  container->SetMain(panel);
-
-  SetTop(container);
+  SetMain(panel);
 
   Dialog::PreInit();
 }
