@@ -19,6 +19,7 @@
 
 #include <cstdlib>
 
+#include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
 #include <Lum/AppInfo.h>
@@ -26,7 +27,6 @@
 #include <Lum/Dialog.h>
 #include <Lum/Panel.h>
 #include <Lum/Space.h>
-#include <Lum/WindowGroup.h>
 
 #include <Lum/Dlg/About.h>
 #include <Lum/Dlg/Msg.h>
@@ -73,13 +73,13 @@ public:
     control(NULL),
     currentImage(NULL)
   {
-    AttachModel(newImageAction);
-    AttachModel(peekAction);
-    AttachModel(blockGroupAction);
-    AttachModel(imageInfoAction);
-    AttachModel(aboutAction);
-    AttachModel(GetOpenedAction());
-    AttachModel(GetClosedAction());
+    Observe(newImageAction);
+    Observe(peekAction);
+    Observe(blockGroupAction);
+    Observe(imageInfoAction);
+    Observe(aboutAction);
+    Observe(GetOpenedAction());
+    Observe(GetClosedAction());
 
     peekAction->Disable();
     blockGroupAction->Disable();
@@ -88,32 +88,16 @@ public:
     downloadListsTask.SetParent(this);
     downloadImageTask.SetParent(this);
 
-    AttachModel(downloadListsTask.GetFinishedAction());
-    AttachModel(downloadImageTask.GetFinishedAction());
-  }
+    Observe(downloadListsTask.GetFinishedAction());
+    Observe(downloadListsTask.GetAbortedAction());
 
-  ~MainDialog()
-  {
-    UnattachModel(downloadImageTask.GetFinishedAction());
-    UnattachModel(downloadListsTask.GetFinishedAction());
-
-    UnattachModel(GetClosedAction());
-    UnattachModel(GetOpenedAction());
-    UnattachModel(aboutAction);
-    UnattachModel(imageInfoAction);
-    UnattachModel(blockGroupAction);
-    UnattachModel(peekAction);
-    UnattachModel(newImageAction);
+    Observe(downloadImageTask.GetFinishedAction());
   }
 
   void PreInit()
   {
     Lum::Button      *button;
     Lum::Panel       *horiz,*vert;
-    Lum::WindowGroup *wGroup;
-
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
 
     horiz=new Lum::HPanel();
     horiz->SetFlex(true,true);
@@ -158,19 +142,21 @@ public:
     button->SetText(L"_Image info");
     vert->Add(button);
 
-    vert->Add(new Lum::VSpace(true));
-
-    button=new Lum::Button;
-    button->SetFlex(true,false);
-    button->SetModel(aboutAction);
-    button->SetText(L"_About");
-    vert->Add(button);
-
     horiz->Add(vert);
 
-    wGroup->SetMain(horiz);
+    SetMain(horiz);
 
-    SetTop(wGroup);
+    Lum::MenuDesc *menu=new Lum::MenuDesc();
+
+    menu
+      ->AddMenuItemSub(_ld(menuProject))
+        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
+    menu
+      ->AddMenuItemSub(_ld(menuHelp))
+        ->AddMenuItemAction(_ld(menuHelpHelp),NULL)
+        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
+
+    SetMenu(menu);
 
     Dialog::PreInit();
   }
@@ -256,7 +242,9 @@ public:
 
   void TriggerNewImage()
   {
+    newImageAction->Off();
     newImageAction->Disable();
+    newImageAction->On(false);
 
     if (GetAvailableImages()<10) {
       TriggerDownloadLists();
@@ -264,7 +252,10 @@ public:
     }
 
     ShowNewImage();
+
+    newImageAction->Off();
     newImageAction->Enable();
+    newImageAction->On(false);
   }
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
@@ -298,7 +289,8 @@ public:
     else if (model==aboutAction && aboutAction->IsFinished()) {
       Lum::Dlg::About::Show(this,info);
     }
-    else if (model==downloadListsTask.GetFinishedAction() && downloadListsTask.GetFinishedAction()->IsFinished()) {
+    else if (model==downloadListsTask.GetFinishedAction() &&
+             downloadListsTask.GetFinishedAction()->IsFinished()) {
       downloadListsTask.GetImageList(images);
 
       if (downloadListsTask.HasError()) {
@@ -321,7 +313,12 @@ public:
 
       newImageAction->Enable();
     }
-    else if (model==downloadImageTask.GetFinishedAction() && downloadImageTask.GetFinishedAction()->IsFinished()) {
+    else if (model==downloadImageTask.GetAbortedAction() &&
+             downloadImageTask.GetAbortedAction()->IsFinished()) {
+      newImageAction->Enable();
+    }
+    else if (model==downloadImageTask.GetFinishedAction() &&
+             downloadImageTask.GetFinishedAction()->IsFinished()) {
       if (downloadImageTask.HasError()) {
         Lum::Dlg::Msg::ShowOk(this,
                               L"Error while downloading image!",
